"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importDefault(require("react"));
const prop_types_1 = __importDefault(require("prop-types"));
const lodash_1 = require("lodash");
const Box_1 = require("@strapi/design-system/Box");
const Flex_1 = require("@strapi/design-system/Flex");
const Link_1 = require("@strapi/design-system/Link");
const Typography_1 = require("@strapi/design-system/Typography");
const icons_1 = require("../icons");
const DiscussionThreadItem_1 = __importDefault(require("../DiscussionThreadItem"));
const utils_1 = require("../../utils");
const LoadingIndicatorOverlay_1 = __importDefault(require("../LoadingIndicatorOverlay"));
const styles_1 = require("../LoadingIndicatorOverlay/styles");
const DiscussionThread = ({ level = [], selected = {}, allowedActions, isReloading, }) => {
    const rootThread = selected?.threadOf;
    return (react_1.default.createElement(styles_1.LoadingIndicatorContainer, { as: Box_1.Box, padding: 4 },
        isReloading && react_1.default.createElement(LoadingIndicatorOverlay_1.default, null),
        react_1.default.createElement(Flex_1.Flex, { as: Box_1.Box, direction: "row", justifyContent: "space-between", marginBottom: 2 },
            react_1.default.createElement(Typography_1.Typography, { variant: "delta", textColor: "neutral800", id: "discussion-thread" }, (0, utils_1.getMessage)("page.details.panel.discussion", "Discussion")),
            rootThread && (react_1.default.createElement(Link_1.Link, { to: (0, utils_1.getUrl)(`discover/${rootThread.id}`), startIcon: icons_1.arrowUp }, (0, utils_1.getMessage)("page.details.panel.discussion.nav.back")))),
        react_1.default.createElement(Flex_1.Flex, { as: "ul", direction: "column", alignItems: "flex-start", marginBottom: 4 },
            rootThread && (react_1.default.createElement(DiscussionThreadItem_1.default, { ...rootThread, allowedActions: allowedActions, isThreadAuthor: true, root: true, pinned: true })),
            level.map((item) => {
                const isSelected = selected.id === item.id;
                const isThreadAuthor = !(0, lodash_1.isNil)(selected?.threadOf?.author?.id) &&
                    selected?.threadOf?.author?.id === item?.author?.id;
                return (react_1.default.createElement(DiscussionThreadItem_1.default, { key: `comment-${item.id}`, ...item, allowedActions: allowedActions, root: (0, lodash_1.isNil)(rootThread), blockedThread: rootThread?.blockedThread || item.blockedThread, isSelected: isSelected, isThreadAuthor: isThreadAuthor }));
            }))));
};
DiscussionThread.propTypes = {
    level: prop_types_1.default.array.isRequired,
    selected: prop_types_1.default.object.isRequired,
    allowedActions: prop_types_1.default.shape({
        canModerate: prop_types_1.default.bool,
        canAccessReports: prop_types_1.default.bool,
        canReviewReports: prop_types_1.default.bool,
    }),
    isReloading: prop_types_1.default.bool,
};
exports.default = DiscussionThread;
//# sourceMappingURL=index.js.map