"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importDefault(require("react"));
const prop_types_1 = __importDefault(require("prop-types"));
const react_query_1 = require("react-query");
const IconButton_1 = require("@strapi/design-system/IconButton");
const icons_1 = require("../icons");
const helper_plugin_1 = require("@strapi/helper-plugin");
const utils_1 = require("../../utils");
const api_1 = require("../../pages/utils/api");
const pluginId_1 = require("../../pluginId");
const DiscussionThreadItemApprovalFlowActions = ({ id, allowedActions: { canModerate }, queryToInvalidate }) => {
    const toggleNotification = (0, helper_plugin_1.useNotification)();
    const queryClient = (0, react_query_1.useQueryClient)();
    const { lockApp, unlockApp } = (0, helper_plugin_1.useOverlayBlocker)();
    const onSuccess = (message) => () => {
        queryClient.invalidateQueries(queryToInvalidate);
        toggleNotification({
            type: "success",
            message: `${pluginId_1.pluginId}.${message}`,
        });
        unlockApp();
    };
    const onError = (err) => {
        (0, utils_1.handleAPIError)(err, toggleNotification);
    };
    const approveItemMutation = (0, react_query_1.useMutation)(api_1.approveItem, {
        onSuccess: onSuccess("page.details.actions.comment.approve.confirmation.success"),
        onError,
        refetchActive: false,
    });
    const rejectItemMutation = (0, react_query_1.useMutation)(api_1.rejectItem, {
        onSuccess: onSuccess("page.details.actions.comment.reject.confirmation.success"),
        onError,
        refetchActive: false,
    });
    const handleApproveClick = () => {
        if (canModerate) {
            lockApp();
            approveItemMutation.mutate(id);
        }
    };
    const handleRejectClick = () => {
        if (canModerate) {
            lockApp();
            rejectItemMutation.mutate(id);
        }
    };
    if (canModerate) {
        return (react_1.default.createElement(react_1.default.Fragment, null,
            react_1.default.createElement(IconButton_1.IconButton, { icon: icons_1.check, label: (0, utils_1.getMessage)("page.details.actions.comment.approve", "Approve"), onClick: handleApproveClick }),
            react_1.default.createElement(IconButton_1.IconButton, { icon: icons_1.cross, label: (0, utils_1.getMessage)("page.details.actions.comment.reject", "Reject"), onClick: handleRejectClick })));
    }
    return null;
};
DiscussionThreadItemApprovalFlowActions.propTypes = {
    id: prop_types_1.default.oneOfType([prop_types_1.default.string, prop_types_1.default.number]).isRequired,
    allowedActions: prop_types_1.default.shape({
        canModerate: prop_types_1.default.bool,
    }),
    wrapped: prop_types_1.default.bool,
};
exports.default = DiscussionThreadItemApprovalFlowActions;
//# sourceMappingURL=index.js.map