"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const Button_1 = require("@strapi/design-system/Button");
const IconButton_1 = require("@strapi/design-system/IconButton");
const helper_plugin_1 = require("@strapi/helper-plugin");
const lodash_1 = require("lodash");
const prop_types_1 = __importDefault(require("prop-types"));
const react_1 = __importStar(require("react"));
const react_query_1 = require("react-query");
const api_1 = require("../../pages/utils/api");
const pluginId_1 = require("../../pluginId");
const utils_1 = require("../../utils");
const ReportsReviewModal_1 = __importDefault(require("../ReportsReviewModal"));
const ReportsReviewTable_1 = __importDefault(require("../ReportsReviewTable"));
const icons_1 = require("../icons");
const DiscussionThreadItemReviewAction = ({ allowedActions: { canModerate, canAccessReports, canReviewReports }, isAnyActionLoading, item, queryToInvalidate }) => {
    const { blockedThread, reports } = item;
    const [reportsReviewVisible, setReportsReviewVisible] = (0, react_1.useState)(false);
    const [storedItems, setStoredItems] = (0, react_1.useState)([]);
    const [selectedItems, setSelectedItems] = (0, react_1.useState)([]);
    const [blockButtonsDisabled, setBlockButtonsDisabled] = (0, react_1.useState)(blockedThread);
    const handleBlockButtonsStateChange = (disabled) => setBlockButtonsDisabled(disabled);
    const toggleNotification = (0, helper_plugin_1.useNotification)();
    const queryClient = (0, react_query_1.useQueryClient)();
    const { lockApp, unlockApp } = (0, helper_plugin_1.useOverlayBlocker)();
    (0, react_1.useEffect)(() => {
        setStoredItems((0, lodash_1.orderBy)(reports, ["resolved", "createdAt"], ["DESC", "DESC"]));
    }, [reportsReviewVisible, reports]);
    const onSuccess = (message = "") => () => {
        queryClient.invalidateQueries(queryToInvalidate);
        if (message) {
            toggleNotification({
                type: "success",
                message: `${pluginId_1.pluginId}.${message}`,
            });
        }
        unlockApp();
    };
    const onError = (err) => () => {
        (0, utils_1.handleAPIError)(err, toggleNotification);
    };
    const mutationConfig = (message) => {
        return {
            onSuccess: onSuccess(message),
            onError
        };
    };
    const onBlockActionClick = async (mutation, onCallback) => {
        lockApp();
        await mutation.mutateAsync(item.id);
        setReportsReviewVisible(false);
    };
    const isNotResolved = (entry) => !entry.resolved;
    const resolveReportMutation = (0, react_query_1.useMutation)(api_1.resolveReport, mutationConfig("page.details.panel.discussion.warnings.reports.dialog.confirmation.success"));
    const resolveCommentMultipleReportsMutation = (0, react_query_1.useMutation)(api_1.resolveCommentMultipleReports, mutationConfig("page.details.panel.discussion.warnings.reports.selected.dialog.confirmation.success"));
    const resolveAllAbuseReportsForCommentMutation = (0, react_query_1.useMutation)(api_1.resolveAllAbuseReportsForComment, mutationConfig());
    const resolveAllAbuseReportsForThreadMutation = (0, react_query_1.useMutation)(api_1.resolveAllAbuseReportsForThread, mutationConfig());
    const blockItemMutation = (0, react_query_1.useMutation)(api_1.blockItem, mutationConfig("page.details.actions.comment.block.confirmation.success"));
    const blockItemThreadMutation = (0, react_query_1.useMutation)(api_1.blockItemThread, mutationConfig("page.details.actions.thread.block.confirmation.success"));
    const handleReportsReviewClick = () => {
        if (canAccessReports) {
            setReportsReviewVisible(true);
        }
    };
    const handleBlockItemClick = () => {
        if (canModerate) {
            onBlockActionClick(blockItemMutation);
        }
    };
    const handleBlockItemThreadClick = () => {
        if (canModerate) {
            onBlockActionClick(blockItemThreadMutation);
        }
    };
    const handleClickResolveSelected = async () => {
        if (canReviewReports) {
            lockApp();
            const items = await resolveCommentMultipleReportsMutation.mutateAsync({
                id: item.id,
                reportIds: selectedItems,
            });
            if (!(0, lodash_1.isEmpty)(items)) {
                const updatedItems = storedItems.map((_) => ({
                    ..._,
                    resolved: selectedItems.includes(_.id) ? true : _.resolved,
                }));
                setStoredItems(updatedItems);
                setSelectedItems([], false);
                handleBlockButtonsStateChange(updatedItems.filter(isNotResolved).length === 0);
            }
        }
    };
    const handleResolveAllAbuseReportsForComment = async () => {
        if (canModerate) {
            await onBlockActionClick(resolveAllAbuseReportsForCommentMutation);
        }
    };
    const handleResolveAllAbuseReportsForThread = async () => {
        if (canModerate) {
            await onBlockActionClick(resolveAllAbuseReportsForThreadMutation);
        }
    };
    const handleReportsReviewClose = async () => {
        await queryClient.invalidateQueries(queryToInvalidate);
        setReportsReviewVisible(false);
    };
    const handleOnClikcBlockComment = (0, react_1.useCallback)(() => {
        handleResolveAllAbuseReportsForComment();
        handleBlockItemClick();
    }, [handleResolveAllAbuseReportsForComment, handleBlockItemClick]);
    const handleOnClikcBlockThread = (0, react_1.useCallback)(() => {
        handleBlockItemThreadClick();
        handleResolveAllAbuseReportsForThread();
    }, [handleBlockItemThreadClick, handleResolveAllAbuseReportsForThread]);
    const onSelectionChange = (selection) => setSelectedItems(selection);
    const isLoading = isAnyActionLoading && resolveReportMutation.isLoading;
    const openReports = reports?.filter(isNotResolved);
    const hasReports = !(0, lodash_1.isEmpty)(openReports);
    const reviewFlowEnabled = canAccessReports && hasReports && !(item.blocked || item.blockedThread);
    const hasAnySelectedItems = selectedItems.length > 0;
    if (reviewFlowEnabled) {
        return (react_1.default.createElement(react_1.default.Fragment, null,
            react_1.default.createElement(IconButton_1.IconButton, { onClick: handleReportsReviewClick, label: (0, utils_1.getMessage)("page.discover.table.reports.review"), icon: icons_1.review }),
            react_1.default.createElement(ReportsReviewModal_1.default, { isVisible: reportsReviewVisible, isActionAsync: isLoading, allowedActions: { canModerate, canAccessReports, canReviewReports }, onClose: handleReportsReviewClose, startActions: react_1.default.createElement(Button_1.Button, { onClick: handleReportsReviewClose, variant: "tertiary" }, (0, utils_1.getMessage)("compontents.confirmation.dialog.button.cancel", "Cancel")), endActions: canModerate && (react_1.default.createElement(react_1.default.Fragment, null,
                    react_1.default.createElement(Button_1.Button, { onClick: handleOnClikcBlockComment, variant: "danger-light", startIcon: icons_1.lock, disabled: blockButtonsDisabled }, (0, utils_1.getMessage)(`page.details.actions.comment.block`, "Block comment")),
                    item.gotThread && (react_1.default.createElement(Button_1.Button, { onClick: handleOnClikcBlockThread, variant: "danger", startIcon: icons_1.lock, disabled: blockButtonsDisabled }, (0, utils_1.getMessage)(`page.details.actions.thread.block`, "Block thread"))),
                    hasAnySelectedItems && (react_1.default.createElement(Button_1.Button, { onClick: handleClickResolveSelected, variant: "success", startIcon: icons_1.check }, (0, utils_1.getMessage)({
                        id: `page.details.panel.discussion.warnings.reports.dialog.actions.resolve.selected`,
                        props: {
                            count: selectedItems.length,
                        },
                    }, "Resolve selected"))))), item: item },
                react_1.default.createElement(ReportsReviewTable_1.default, { commentId: item.id, items: storedItems, selectedItems: selectedItems, mutation: resolveReportMutation, updateItems: setStoredItems, allowedActions: { canAccessReports, canReviewReports }, onBlockButtonsStateChange: handleBlockButtonsStateChange, onSelectionChange: onSelectionChange }))));
    }
    return null;
};
DiscussionThreadItemReviewAction.propTypes = {
    item: prop_types_1.default.object.isRequired,
    isAnyActionLoading: prop_types_1.default.bool,
    allowedActions: prop_types_1.default.shape({
        canModerate: prop_types_1.default.bool,
        canAccessReports: prop_types_1.default.bool,
        canReviewReports: prop_types_1.default.bool,
    }),
    queryToInvalidate: prop_types_1.default.string
};
exports.default = DiscussionThreadItemReviewAction;
//# sourceMappingURL=index.js.map