"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importStar(require("react"));
const react_intl_1 = require("react-intl");
const lodash_1 = require("lodash");
const BaseCheckbox_1 = require("@strapi/design-system/BaseCheckbox");
const Flex_1 = require("@strapi/design-system/Flex");
const Table_1 = require("@strapi/design-system/Table");
const Typography_1 = require("@strapi/design-system/Typography");
const VisuallyHidden_1 = require("@strapi/design-system/VisuallyHidden");
const icons_1 = require("../icons");
const helper_plugin_1 = require("@strapi/helper-plugin");
const utils_1 = require("../../utils");
const constants_1 = require("../../utils/constants");
const StatusBadge_1 = __importDefault(require("../StatusBadge"));
const styles_1 = require("../ActionButton/styles");
const ReportsReviewTable = ({ commentId, items, selectedItems = [], mutation, updateItems, allowedActions: { canAccessReports, canReviewReports }, onBlockButtonsStateChange, onSelectionChange, }) => {
    const { formatDate } = (0, react_intl_1.useIntl)();
    const { lockApp } = (0, helper_plugin_1.useOverlayBlocker)();
    const renderStatus = (resolved) => {
        const status = resolved ? constants_1.REPORT_STATUS.RESOLVED : constants_1.REPORT_STATUS.OPEN;
        let color = "alternative";
        switch (status) {
            case constants_1.REPORT_STATUS.RESOLVED:
                color = "success";
                break;
            case constants_1.REPORT_STATUS.OPEN:
                color = "danger";
        }
        return (react_1.default.createElement(StatusBadge_1.default, { backgroundColor: `${color}100`, textColor: `${color}600`, color: color }, (0, utils_1.getMessage)(`page.details.panel.discussion.warnings.reports.dialog.status.${status}`, status)));
    };
    const renderReason = (reason) => {
        let color = "neutral";
        switch (reason) {
            case constants_1.REPORT_REASON.DISCRIMINATION:
                color = "danger";
                break;
            case constants_1.REPORT_REASON.BAD_LANGUAGE:
                color = "warning";
        }
        return (react_1.default.createElement(StatusBadge_1.default, { backgroundColor: `${color}100`, textColor: `${color}600`, color: color }, (0, utils_1.getMessage)(`page.details.panel.discussion.warnings.reports.dialog.reason.${reason}`, reason)));
    };
    const handleItemSelectionChange = (selection, value) => {
        if ((0, lodash_1.isArray)(selection)) {
            onSelectionChange(value ? selection : []);
        }
        else {
            onSelectionChange([...selectedItems, selection].filter((item) => value || selection !== item));
        }
    };
    const isNotResolved = (entry) => !entry.resolved;
    const unresolvedItems = items.filter(isNotResolved);
    const areAllItemsSelected = () => !(0, lodash_1.isEmpty)(selectedItems)
        ? selectedItems.length === unresolvedItems.length
        : false;
    const isItemSelected = (id) => selectedItems.includes(id);
    const handleClickResolve = async (reportId) => {
        if (canReviewReports) {
            lockApp();
            const item = await mutation.mutateAsync({
                id: commentId,
                reportId,
            });
            if (item) {
                const updatedItems = items.map((_) => ({
                    ..._,
                    resolved: reportId === _.id ? true : _.resolved,
                }));
                updateItems(updatedItems);
                onSelectionChange(selectedItems.filter((_) => _ !== reportId));
                onBlockButtonsStateChange(updatedItems.filter(isNotResolved).length === 0);
            }
        }
    };
    const handleValueChange = (0, react_1.useCallback)((value) => handleItemSelectionChange(unresolvedItems.map((_) => _.id), value), [unresolvedItems, handleItemSelectionChange]);
    if ((0, lodash_1.isEmpty)(items)) {
        return null;
    }
    const COL_COUNT = 6;
    if (canAccessReports) {
        return (react_1.default.createElement(Table_1.Table, { colCount: COL_COUNT, rowCount: items.length },
            react_1.default.createElement(Table_1.Thead, null,
                react_1.default.createElement(Table_1.Tr, null,
                    react_1.default.createElement(Table_1.Th, null,
                        react_1.default.createElement(BaseCheckbox_1.BaseCheckbox, { "aria-label": (0, utils_1.getMessage)("page.details.panel.discussion.warnings.reports.dialog.selectAll"), value: areAllItemsSelected(), disabled: (0, lodash_1.isEmpty)(unresolvedItems), onValueChange: handleValueChange })),
                    react_1.default.createElement(Table_1.Th, null,
                        react_1.default.createElement(Typography_1.Typography, { variant: "sigma" }, (0, utils_1.getMessage)("page.details.panel.discussion.warnings.reports.dialog.reason"))),
                    react_1.default.createElement(Table_1.Th, null,
                        react_1.default.createElement(Typography_1.Typography, { variant: "sigma" }, (0, utils_1.getMessage)("page.details.panel.discussion.warnings.reports.dialog.content"))),
                    react_1.default.createElement(Table_1.Th, null,
                        react_1.default.createElement(Typography_1.Typography, { variant: "sigma" }, (0, utils_1.getMessage)("page.details.panel.discussion.warnings.reports.dialog.createdAt"))),
                    react_1.default.createElement(Table_1.Th, null,
                        react_1.default.createElement(Typography_1.Typography, { variant: "sigma" }, (0, utils_1.getMessage)("page.details.panel.discussion.warnings.reports.dialog.status"))),
                    canReviewReports && (react_1.default.createElement(Table_1.Th, null,
                        react_1.default.createElement(VisuallyHidden_1.VisuallyHidden, null, (0, utils_1.getMessage)("page.details.panel.discussion.warnings.reports.dialog.actions")))))),
            react_1.default.createElement(Table_1.Tbody, null, items.map((entry) => (react_1.default.createElement(Table_1.Tr, { key: entry.id },
                react_1.default.createElement(Table_1.Td, null,
                    react_1.default.createElement(BaseCheckbox_1.BaseCheckbox, { "aria-label": (0, utils_1.getMessage)("page.details.panel.discussion.warnings.reports.dialog.select"), value: isItemSelected(entry.id), disabled: entry.resolved, onValueChange: (value) => handleItemSelectionChange(entry.id, value) })),
                react_1.default.createElement(Table_1.Td, null,
                    react_1.default.createElement(Typography_1.Typography, { textColor: "neutral800" }, renderReason(entry.reason))),
                react_1.default.createElement(Table_1.Td, null,
                    react_1.default.createElement(Typography_1.Typography, { textColor: "neutral800" }, entry.content)),
                react_1.default.createElement(Table_1.Td, null,
                    react_1.default.createElement(Typography_1.Typography, { textColor: "neutral800" }, formatDate(entry.createdAt, {
                        dateStyle: "short",
                        timeStyle: "short",
                    }))),
                react_1.default.createElement(Table_1.Td, null, renderStatus(entry.resolved)),
                canReviewReports && (react_1.default.createElement(Table_1.Td, null, !entry.resolved && (react_1.default.createElement(Flex_1.Flex, { direction: "column", alignItems: "flex-end" },
                    react_1.default.createElement(styles_1.ActionButton, { isSingle: true, onClick: () => handleClickResolve(entry.id), startIcon: icons_1.check, variant: "success" }, (0, utils_1.getMessage)("page.details.panel.discussion.warnings.reports.dialog.actions.resolve", "resolve"))))))))))));
    }
    return null;
};
exports.default = ReportsReviewTable;
//# sourceMappingURL=index.js.map