"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importStar(require("react"));
const styled_components_1 = __importDefault(require("styled-components"));
const react_intl_1 = require("react-intl");
const Typography_1 = require("@strapi/design-system/Typography");
const Box_1 = require("@strapi/design-system/Box");
const Stack_1 = require("@strapi/design-system/Stack");
const helper_plugin_1 = require("@strapi/helper-plugin");
const Editor_1 = __importDefault(require("./Editor"));
const WysiwygNav_1 = __importDefault(require("./WysiwygNav"));
const WysiwygFooter_1 = __importDefault(require("./WysiwygFooter"));
const Hint_1 = __importDefault(require("../Hint"));
const utils_1 = require("./utils/utils");
const EditorLayout_1 = require("./EditorLayout");
const LabelAction = (0, styled_components_1.default)(Box_1.Box) `
  svg path {
    fill: ${({ theme }) => theme.colors.neutral500};
  }
`;
const TypographyAsterisk = (0, styled_components_1.default)(Typography_1.Typography) `
  line-height: 0;
`;
const Wysiwyg = ({ description, disabled, error, intlLabel, labelAction, name, onChange, placeholder, value, required, }) => {
    const { formatMessage } = (0, react_intl_1.useIntl)();
    const textareaRef = (0, react_1.useRef)(null);
    const editorRef = (0, react_1.useRef)(null);
    const [isPreviewMode, setIsPreviewMode] = (0, react_1.useState)(false);
    const [mediaLibVisible, setMediaLibVisible] = (0, react_1.useState)(false);
    const [isExpandMode, setIsExpandMode] = (0, react_1.useState)(false);
    const { components } = (0, helper_plugin_1.useLibrary)();
    const MediaLibraryDialog = components['media-library'];
    const handleToggleMediaLib = () => setMediaLibVisible(prev => !prev);
    const handleTogglePreviewMode = () => setIsPreviewMode(prev => !prev);
    const handleToggleExpand = () => {
        setIsPreviewMode(false);
        setIsExpandMode(prev => !prev);
    };
    const handleActionClick = (value, currentEditorRef, togglePopover) => {
        switch (value) {
            case 'Link':
            case 'Strikethrough': {
                (0, utils_1.markdownHandler)(currentEditorRef, value);
                togglePopover();
                break;
            }
            case 'Code':
            case 'Quote': {
                (0, utils_1.quoteAndCodeHandler)(currentEditorRef, value);
                togglePopover();
                break;
            }
            case 'Bold':
            case 'Italic':
            case 'Underline': {
                (0, utils_1.markdownHandler)(currentEditorRef, value);
                break;
            }
            case 'BulletList':
            case 'NumberList': {
                (0, utils_1.listHandler)(currentEditorRef, value);
                togglePopover();
                break;
            }
            case 'h1':
            case 'h2':
            case 'h3':
            case 'h4':
            case 'h5':
            case 'h6': {
                (0, utils_1.titleHandler)(currentEditorRef, value);
                break;
            }
            default: {
            }
        }
    };
    const handleSelectAssets = (files) => {
        const formattedFiles = files.map((f) => ({
            alt: f.alternativeText || f.name,
            url: (0, helper_plugin_1.prefixFileUrlWithBackendUrl)(f.url),
            mime: f.mime,
        }));
        (0, utils_1.insertFile)(editorRef, formattedFiles);
        setMediaLibVisible(false);
    };
    const formattedPlaceholder = placeholder
        ? formatMessage({ id: placeholder.id, defaultMessage: placeholder.defaultMessage }, { ...placeholder.values })
        : '';
    const label = intlLabel.id
        ? formatMessage({ id: intlLabel.id, defaultMessage: intlLabel.defaultMessage }, { ...intlLabel.values })
        : name;
    return (react_1.default.createElement(react_1.default.Fragment, null,
        react_1.default.createElement(Stack_1.Stack, { spacing: 1 },
            react_1.default.createElement(Stack_1.Stack, { horizontal: true, spacing: 1 },
                react_1.default.createElement(Typography_1.Typography, { variant: "pi", fontWeight: "bold", textColor: "neutral800" },
                    label,
                    required && react_1.default.createElement(TypographyAsterisk, { textColor: "danger600" }, "*")),
                labelAction && react_1.default.createElement(LabelAction, { paddingLeft: 1 }, labelAction)),
            react_1.default.createElement(EditorLayout_1.EditorLayout, { isExpandMode: isExpandMode, error: error, previewContent: value, onCollapse: handleToggleExpand },
                react_1.default.createElement(WysiwygNav_1.default, { isExpandMode: isExpandMode, editorRef: editorRef, isPreviewMode: isPreviewMode, onActionClick: handleActionClick, onToggleMediaLib: handleToggleMediaLib, onTogglePreviewMode: isExpandMode ? undefined : handleTogglePreviewMode, disabled: disabled }),
                react_1.default.createElement(Editor_1.default, { disabled: disabled, isExpandMode: isExpandMode, editorRef: editorRef, error: error, isPreviewMode: isPreviewMode, name: name, onChange: onChange, placeholder: formattedPlaceholder, textareaRef: textareaRef, value: value }),
                !isExpandMode && react_1.default.createElement(WysiwygFooter_1.default, { onToggleExpand: handleToggleExpand })),
            react_1.default.createElement(Hint_1.default, { description: description, name: name, error: error, id: name })),
        error && (react_1.default.createElement(Box_1.Box, { paddingTop: 1 },
            react_1.default.createElement(Typography_1.Typography, { variant: "pi", textColor: "danger600", "data-strapi-field-error": true }, error))),
        mediaLibVisible && (react_1.default.createElement(MediaLibraryDialog, { onClose: handleToggleMediaLib, onSelectAssets: handleSelectAssets }))));
};
exports.default = Wysiwyg;
//# sourceMappingURL=index.js.map