"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getApprovalStatusOptions = exports.getFilterByOptions = exports.getSortByDateOptions = exports.getRenderTypeOptions = exports.handlePopulateChange = exports.handleStateSliceChange = exports.assertCorrectState = exports.toOutput = exports.fromInput = exports.asString = void 0;
const lodash_1 = require("lodash");
const utils_1 = require("../../../../utils");
const consts_1 = require("./consts");
const asString = () => "";
exports.asString = asString;
const fromInput = (value) => {
    (0, utils_1.assertString)(value);
    let state = JSON.parse(value);
    if (!state) {
        console.group("[Comments]");
        console.warn("Empty state provided from the back-end");
        console.groupEnd();
        state = consts_1.DEFAULTS;
    }
    assertCorrectState(state);
    if (state.filterBy === "DATE_CREATED" && state.filterByValue) {
        state.filterByValue = new Date(state.filterByValue);
    }
    return state;
};
exports.fromInput = fromInput;
const toOutput = (state) => JSON.stringify(state);
exports.toOutput = toOutput;
function assertCorrectState(state) {
    if (typeof state.commentsNumber !== "number") {
        throw new utils_1.ValidationError("Comments number is not a number");
    }
    if (state.populate && !Array.isArray(state.populate)) {
        throw new utils_1.ValidationError("Comments populate is not an array");
    }
    stringFields.forEach((field) => {
        if (state[field] && typeof state[field] !== "string") {
            (0, utils_1.assertString)(state[field]);
        }
    });
}
exports.assertCorrectState = assertCorrectState;
const handleStateSliceChange = (key, setState) => (value) => {
    return setState((current) => ({
        ...current,
        [key]: value,
    }));
};
exports.handleStateSliceChange = handleStateSliceChange;
const handlePopulateChange = (key, setState) => () => {
    return setState((current) => {
        const populate = current.populate || [];
        return {
            ...current,
            populate: populate.includes(key)
                ? populate.filter((field) => field !== key)
                : (0, lodash_1.uniq)(populate.concat(key)),
        };
    });
};
exports.handlePopulateChange = handlePopulateChange;
const getRenderTypeOptions = (translate) => ([
    {
        value: "TREE",
        label: translate({
            id: "customField.comments.input.renderType.option.tree.label",
            defaultMessage: "Tree",
        }),
    },
    {
        value: "FLAT",
        label: translate({
            id: "customField.comments.input.renderType.option.flat.label",
            defaultMessage: "Flat list",
        }),
    },
]);
exports.getRenderTypeOptions = getRenderTypeOptions;
const getSortByDateOptions = (translate) => ([
    {
        value: "ASC",
        label: translate({
            id: "customField.comments.input.sortByDate.option.asc.label",
            defaultMessage: "Ascending",
        }),
    },
    {
        value: "DESC",
        label: translate({
            id: "customField.comments.input.sortByDate.option.desc.label",
            defaultMessage: "Descending",
        }),
    },
]);
exports.getSortByDateOptions = getSortByDateOptions;
const getFilterByOptions = (translate) => ([
    {
        value: "DATE_CREATED",
        label: translate({
            id: "customField.comments.input.filterBy.option.dateCreated.label",
            defaultMessage: "Creation date",
        }),
    },
    {
        value: "APPROVAL_STATUS",
        label: translate({
            id: "customField.comments.input.filterBy.option.approvalStatus.label",
            defaultMessage: "Approval Status",
        }),
    },
]);
exports.getFilterByOptions = getFilterByOptions;
const getApprovalStatusOptions = (translate) => ([
    {
        value: utils_1.APPROVAL_STATUS.APPROVED,
        label: translate({
            id: "customField.comments.input.filterBy.option.approvalStatus.option.approved.label",
            defaultMessage: "Approved",
        }),
    },
    {
        value: utils_1.APPROVAL_STATUS.PENDING,
        label: translate({
            id: "customField.comments.input.filterBy.option.approvalStatus.option.pending.label",
            defaultMessage: "Pending",
        }),
    },
    {
        value: utils_1.APPROVAL_STATUS.REJECTED,
        label: translate({
            id: "customField.comments.input.filterBy.option.approvalStatus.option.rejected.label",
            defaultMessage: "Rejected",
        }),
    },
]);
exports.getApprovalStatusOptions = getApprovalStatusOptions;
const stringFields = [
    "renderType",
    "sortByDate",
    "filterBy",
    "filterByValue",
];
//# sourceMappingURL=utils.js.map