"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const react_query_1 = require("react-query");
const api_1 = require("../pages/Settings/utils/api");
const pluginId_1 = require("../pluginId");
const useConfig = (toggleNotification) => {
    const queryClient = (0, react_query_1.useQueryClient)();
    const fetch = (0, react_query_1.useQuery)("get-config", () => (0, api_1.fetchConfig)(toggleNotification));
    const handleError = (type, callback = () => { }) => {
        toggleNotification({
            type: "warning",
            message: `${pluginId_1.pluginId}.page.settings.notification.${type}.error`,
        });
        callback();
    };
    const handleSuccess = (type, callback = () => { }, invalidateQueries = true) => {
        if (invalidateQueries) {
            queryClient.invalidateQueries("get-config");
        }
        toggleNotification({
            type: "success",
            message: `${pluginId_1.pluginId}.page.settings.notification.${type}.success`,
        });
        callback();
    };
    const submitMutation = (0, react_query_1.useMutation)(api_1.updateConfig, {
        onSuccess: () => handleSuccess("submit"),
        onError: () => handleError("submit"),
    });
    const restoreMutation = (0, react_query_1.useMutation)(api_1.restoreConfig, {
        onSuccess: () => handleSuccess("restore"),
        onError: () => handleError("restore"),
    });
    const restartMutation = (0, react_query_1.useMutation)(api_1.restartStrapi, {
        onSuccess: () => handleSuccess("restart", () => { }, false),
        onError: () => handleError("restart"),
    });
    return { fetch, restartMutation, submitMutation, restoreMutation };
};
exports.default = useConfig;
//# sourceMappingURL=useConfig.js.map