"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const react_query_1 = require("react-query");
const helper_plugin_1 = require("@strapi/helper-plugin");
const utils_1 = require("../utils");
const api_1 = require("../pages/utils/api");
const useReportsActionsHandlers = ({ allowedActions, commentId, mutation, onSelectionChange, reports, selectedReports, updateReports, }) => {
    const { canModerate, canReviewReports } = allowedActions;
    const { lockApp, unlockApp } = (0, helper_plugin_1.useOverlayBlocker)();
    const queryClient = (0, react_query_1.useQueryClient)();
    const toggleNotification = (0, helper_plugin_1.useNotification)();
    const onSuccess = async () => {
        await queryClient.invalidateQueries("get-data");
        unlockApp();
    };
    const onError = (err) => {
        (0, utils_1.handleAPIError)(err, toggleNotification);
    };
    const mutationConfig = {
        onSuccess,
        onError,
        refetchActive: false,
    };
    const resolveAllAbuseReportsForCommentMutation = (0, react_query_1.useMutation)(api_1.resolveAllAbuseReportsForComment, mutationConfig);
    const resolveAllAbuseReportsForThreadMutation = (0, react_query_1.useMutation)(api_1.resolveAllAbuseReportsForThread, mutationConfig);
    const blockItemMutation = (0, react_query_1.useMutation)(api_1.blockItem, mutationConfig);
    const unblockItemMutation = (0, react_query_1.useMutation)(api_1.unblockItem, mutationConfig);
    const blockItemThreadMutation = (0, react_query_1.useMutation)(api_1.blockItemThread, mutationConfig);
    const unblockItemThreadMutation = (0, react_query_1.useMutation)(api_1.unblockItemThread, mutationConfig);
    const handleClickResolve = async (reportId) => {
        if (canReviewReports) {
            lockApp();
            const item = await mutation.mutateAsync({
                id: commentId,
                reportId,
            });
            if (item) {
                const updatedReports = reports.map((report) => ({
                    ...report,
                    resolved: reportId === report.id ? true : report.resolved,
                }));
                updateReports(updatedReports);
                onSelectionChange(selectedReports.filter((id) => id !== reportId));
            }
        }
    };
    const perform = (action) => (id) => {
        if (canModerate) {
            lockApp();
            action(id);
        }
    };
    const handleBlockItemClick = perform(blockItemMutation.mutate);
    const handleUnblockItemClick = perform(unblockItemMutation.mutate);
    const handleBlockItemThreadClick = perform(blockItemThreadMutation.mutate);
    const handleUnblockThreadClick = perform(unblockItemThreadMutation.mutate);
    const handleResolveAllAbuseReportsForComment = perform(resolveAllAbuseReportsForCommentMutation.mutate);
    const handleResolveAllAbuseReportsForThread = perform(resolveAllAbuseReportsForThreadMutation.mutate);
    return {
        handleBlockItemClick,
        handleBlockItemThreadClick,
        handleClickResolve,
        handleResolveAllAbuseReportsForComment,
        handleResolveAllAbuseReportsForThread,
        handleUnblockItemClick,
        handleUnblockThreadClick,
    };
};
exports.default = useReportsActionsHandlers;
//# sourceMappingURL=useReportsActionsHandlers.js.map