"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importDefault(require("react"));
const prop_types_1 = __importDefault(require("prop-types"));
const lodash_1 = require("lodash");
const Box_1 = require("@strapi/design-system/Box");
const Divider_1 = require("@strapi/design-system/Divider");
const Flex_1 = require("@strapi/design-system/Flex");
const Stack_1 = require("@strapi/design-system/Stack");
const Typography_1 = require("@strapi/design-system/Typography");
const utils_1 = require("../../../../utils");
const DetailsFilters_1 = __importDefault(require("../DetailsFilters"));
const DetailsEntity = ({ data = {}, schema = {}, config = {}, filters, onFiltersChange, }) => {
    const { entryLabel = {} } = config;
    const { attributes = {} } = schema;
    const keys = Object.keys(attributes);
    const entityLabelKey = (0, lodash_1.first)(entryLabel[data?.uid]);
    const FIELDS_LIMIT = 5;
    const itemKeys = (0, lodash_1.take)(keys.filter((_) => attributes[_].type === "string" &&
        !(0, lodash_1.isNil)(data[_]) &&
        _ !== entityLabelKey), FIELDS_LIMIT);
    const formatLabel = (label = "") => label
        .split("_")
        .map((_) => (0, lodash_1.capitalize)(_))
        .join(" ");
    const entityIsRenderable = data && !(0, lodash_1.isEmpty)(data) && (!(0, lodash_1.isEmpty)(itemKeys) || data[entityLabelKey]);
    return (react_1.default.createElement(Box_1.Box, { padding: 4 },
        entityIsRenderable && (react_1.default.createElement(Box_1.Box, { marginBottom: 4 },
            react_1.default.createElement(Typography_1.Typography, { variant: "sigma", textColor: "neutral600", id: "entity-details" }, (0, utils_1.getMessage)("page.details.panel.entity", "Details")),
            react_1.default.createElement(Box_1.Box, { paddingTop: 2, paddingBottom: 4 },
                react_1.default.createElement(Divider_1.Divider, null)),
            react_1.default.createElement(Stack_1.Stack, { size: itemKeys.length },
                react_1.default.createElement(Flex_1.Flex, { direction: "column", alignItems: "flex-start" },
                    react_1.default.createElement(Typography_1.Typography, { fontWeight: "bold" }, formatLabel(entityLabelKey)),
                    react_1.default.createElement(Typography_1.Typography, null, data[entityLabelKey])),
                itemKeys.map((_) => (react_1.default.createElement(Flex_1.Flex, { key: `prop_${_}`, direction: "column", alignItems: "flex-start" },
                    react_1.default.createElement(Typography_1.Typography, { fontWeight: "bold" }, formatLabel(_)),
                    react_1.default.createElement(Typography_1.Typography, null, data[_]))))))),
        react_1.default.createElement(Box_1.Box, null,
            react_1.default.createElement(Typography_1.Typography, { variant: "sigma", textColor: "neutral600", id: "view-filters" }, (0, utils_1.getMessage)("page.details.filters.label", "View")),
            react_1.default.createElement(Box_1.Box, { paddingTop: 2, paddingBottom: 4 },
                react_1.default.createElement(Divider_1.Divider, null)),
            react_1.default.createElement(DetailsFilters_1.default, { data: filters, onChange: onFiltersChange }))));
};
DetailsEntity.propTypes = {
    data: prop_types_1.default.object.isRequired,
    schema: prop_types_1.default.object.isRequired,
    config: prop_types_1.default.object.isRequired,
    filters: prop_types_1.default.object.isRequired,
    onFiltersChange: prop_types_1.default.func.isRequired,
};
exports.default = DetailsEntity;
//# sourceMappingURL=index.js.map