"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.mapDispatchToProps = void 0;
const BaseCheckbox_1 = require("@strapi/design-system/BaseCheckbox");
const Box_1 = require("@strapi/design-system/Box");
const Button_1 = require("@strapi/design-system/Button");
const Layout_1 = require("@strapi/design-system/Layout");
const LiveRegions_1 = require("@strapi/design-system/LiveRegions");
const Table_1 = require("@strapi/design-system/Table");
const Typography_1 = require("@strapi/design-system/Typography");
const helper_plugin_1 = require("@strapi/helper-plugin");
const icons_1 = require("../../components/icons");
const lodash_1 = require("lodash");
const react_1 = __importStar(require("react"));
const react_fast_compare_1 = __importDefault(require("react-fast-compare"));
const react_query_1 = require("react-query");
const react_redux_1 = require("react-redux");
const react_router_dom_1 = require("react-router-dom");
const redux_1 = require("redux");
const Nav_1 = __importDefault(require("../../components/Nav"));
const TableFilters_1 = __importDefault(require("../../components/TableFilters"));
const TablePagination_1 = __importDefault(require("../../components/TablePagination"));
const permissions_1 = __importDefault(require("../../permissions"));
const utils_1 = require("../../utils");
const getUrl_1 = __importDefault(require("../../utils/getUrl"));
const selectors_1 = __importDefault(require("../App/reducer/selectors"));
const api_1 = require("../utils/api");
const ReportsTableRow_1 = __importDefault(require("./components/ReportsTableRow"));
const api_2 = require("./utils/api");
const filtersSchema_1 = __importDefault(require("./utils/filtersSchema"));
const NoAccessPage_1 = __importDefault(require("../NoAccessPage"));
const tableHeaders = [
    "page.reports.table.header.id",
    "page.reports.table.header.reason",
    "page.reports.table.header.content",
    "page.reports.table.header.status",
    "page.reports.table.header.issueDate",
    "page.reports.table.header.relatedComment",
    "page.reports.table.header.actions",
];
const COL_COUNT = 8;
const Reports = ({ config }) => {
    const [storedReports, setStoredReports] = (0, react_1.useState)([]);
    const [selectedReports, setSelectedReports] = (0, react_1.useState)([]);
    (0, helper_plugin_1.useFocusWhenNavigate)();
    const { push } = (0, react_router_dom_1.useHistory)();
    const { notifyStatus } = (0, LiveRegions_1.useNotifyAT)();
    const { trackUsage } = (0, helper_plugin_1.useTracking)();
    const trackUsageRef = (0, react_1.useRef)(trackUsage);
    const toggleNotification = (0, helper_plugin_1.useNotification)();
    const [{ query: queryParams }] = (0, helper_plugin_1.useQueryParams)();
    const _q = queryParams?._q || "";
    const queryClient = (0, react_query_1.useQueryClient)();
    const { lockApp, unlockApp } = (0, helper_plugin_1.useOverlayBlocker)();
    const viewPermissions = (0, react_1.useMemo)(() => ({
        access: permissions_1.default.access,
        moderate: permissions_1.default.moderate,
        accessReports: permissions_1.default.reports,
        reviewReports: permissions_1.default.reportsReview,
    }), []);
    const { isLoading: isLoadingForPermissions, allowedActions: { canAccess, canModerate, canAccessReports, canReviewReports, }, } = (0, helper_plugin_1.useRBAC)(viewPermissions);
    const { isLoading: isLoadingForData, data: { result, pagination = {} }, isFetching, } = (0, react_query_1.useQuery)(["get-data", queryParams, canAccess], () => (0, api_2.fetchReportsData)(queryParams, toggleNotification), {
        initialData: {},
    });
    (0, react_1.useEffect)(() => {
        setStoredReports(result);
    }, [result, storedReports]);
    const handleClickDisplay = (id) => {
        push((0, getUrl_1.default)(`discover/${id}`));
    };
    const onSuccess = () => async () => {
        await queryClient.invalidateQueries("get-data");
        unlockApp();
    };
    const onError = (err) => {
        (0, utils_1.handleAPIError)(err, toggleNotification);
    };
    const onSelectionChange = (selection) => setSelectedReports(selection);
    const handleItemSelectionChange = (selection, value) => {
        if ((0, lodash_1.isArray)(selection)) {
            onSelectionChange(value ? selection : []);
        }
        else {
            onSelectionChange([...selectedReports, selection].filter((item) => value || selection !== item));
        }
    };
    const areAllItemsSelected = () => !(0, lodash_1.isEmpty)(selectedReports)
        ? selectedReports.length === storedReports.length
        : false;
    const isItemSelected = (id) => selectedReports.includes(id);
    const hasAnySelectedReports = selectedReports.length > 0;
    const onValueChange = (0, react_1.useCallback)((value) => {
        handleItemSelectionChange(storedReports.map((_) => _.id), value);
    }, [storedReports]);
    const resolveReportMutation = (0, react_query_1.useMutation)(api_1.resolveReport, {
        onSuccess: onSuccess(),
        onError,
        refetchActive: false,
    });
    const resolveMultipleReportsMutation = (0, react_query_1.useMutation)(api_1.resolveMultipleReports, {
        onSuccess: onSuccess(),
        onError,
        refetchActive: false,
    });
    const handleClickResolveSelected = async () => {
        if (canReviewReports) {
            lockApp();
            const items = await resolveMultipleReportsMutation.mutateAsync(selectedReports);
            if (!(0, lodash_1.isEmpty)(items)) {
                const updatedReports = storedReports.map((_) => ({
                    ..._,
                    resolved: selectedReports.includes(_.id) ? true : _.resolved,
                }));
                setStoredReports(updatedReports);
                setSelectedReports([], false);
            }
        }
    };
    const isLoading = isLoadingForData || isFetching;
    const { total } = pagination;
    const emptyLayout = {
        comments: {
            id: (0, utils_1.getMessage)("page.reports.table.empty"),
            defaultMessage: "You don't have any reports yet.",
        },
        search: {
            id: (0, utils_1.getMessage)("page.reports.table.empty.search"),
            defaultMessage: "No reports match the search.",
        },
    };
    const emptyContent = _q ? "search" : "comments";
    return canAccess ? (react_1.default.createElement(Box_1.Box, { background: "neutral100" },
        react_1.default.createElement(Layout_1.Layout, null, isLoading || isLoadingForPermissions ? (react_1.default.createElement(helper_plugin_1.LoadingIndicatorPage, null)) : (react_1.default.createElement(Layout_1.Layout, { sideNav: react_1.default.createElement(Nav_1.default, { visible: true }) },
            react_1.default.createElement(react_1.default.Fragment, null,
                react_1.default.createElement(Layout_1.HeaderLayout, { title: (0, utils_1.getMessage)("page.reports.header"), subtitle: `${total} ${(0, utils_1.getMessage)("page.discover.header.count")}`, as: "h2" }),
                react_1.default.createElement(Layout_1.ActionLayout, { startActions: react_1.default.createElement(react_1.default.Fragment, null,
                        react_1.default.createElement(helper_plugin_1.SearchURLQuery, { label: (0, utils_1.getMessage)("search.label", "Search", false) }),
                        react_1.default.createElement(TableFilters_1.default, { displayedFilters: filtersSchema_1.default }),
                        hasAnySelectedReports && (react_1.default.createElement(Button_1.Button, { variant: "success", onClick: handleClickResolveSelected, startIcon: icons_1.check }, (0, utils_1.getMessage)({
                            id: `page.details.panel.discussion.warnings.reports.dialog.actions.resolve.selected`,
                            props: {
                                count: selectedReports.length,
                            },
                        }, "Resolve selected")))) }),
                react_1.default.createElement(Layout_1.ContentLayout, null, !(0, lodash_1.isEmpty)(result) ? (react_1.default.createElement(react_1.default.Fragment, null,
                    react_1.default.createElement(Table_1.Table, { colCount: COL_COUNT, rowCount: result.length },
                        react_1.default.createElement(Table_1.Thead, null,
                            react_1.default.createElement(Table_1.Tr, null,
                                react_1.default.createElement(Table_1.Th, null,
                                    react_1.default.createElement(BaseCheckbox_1.BaseCheckbox, { "aria-label": (0, utils_1.getMessage)("page.details.panel.discussion.warnings.reports.dialog.selectAll"), value: areAllItemsSelected(), disabled: (0, lodash_1.isEmpty)(storedReports), onValueChange: onValueChange })),
                                tableHeaders.map((title) => (react_1.default.createElement(Table_1.Th, null,
                                    react_1.default.createElement(Typography_1.Typography, { variant: "sigma" }, (0, utils_1.getMessage)(title))))))),
                        react_1.default.createElement(Table_1.Tbody, null, result.map((entry) => {
                            return (react_1.default.createElement(ReportsTableRow_1.default, { key: `comment-${entry.id}`, config: config, item: entry, allowedActions: {
                                    canModerate,
                                    canAccessReports,
                                    canReviewReports,
                                }, onClick: () => handleClickDisplay(entry.related.id), mutation: resolveReportMutation, reports: storedReports, updateReports: setStoredReports, selectedReports: selectedReports, onSelectionChange: onSelectionChange, isChecked: isItemSelected, handleItemSelectionChange: handleItemSelectionChange }));
                        }))),
                    react_1.default.createElement(TablePagination_1.default, { pagination: { pageCount: pagination?.pageCount || 1 } }))) : (react_1.default.createElement(helper_plugin_1.EmptyStateLayout, { content: emptyLayout[emptyContent] }))))))))) :
        react_1.default.createElement(NoAccessPage_1.default, null);
};
const mapStateToProps = (0, selectors_1.default)();
const mapDispatchToProps = (dispatch) => {
    return (0, redux_1.bindActionCreators)({}, dispatch);
};
exports.mapDispatchToProps = mapDispatchToProps;
const withConnect = (0, react_redux_1.connect)(mapStateToProps, exports.mapDispatchToProps);
exports.default = (0, redux_1.compose)(withConnect)((0, react_1.memo)(Reports, react_fast_compare_1.default));
//# sourceMappingURL=index.js.map