"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.updateComment = exports.postComment = exports.resolveAllAbuseReportsForThread = exports.resolveAllAbuseReportsForComment = exports.resolveMultipleReports = exports.resolveCommentMultipleReports = exports.resolveReport = exports.unblockItemThread = exports.blockItemThread = exports.deleteItem = exports.rejectItem = exports.approveItem = exports.unblockItem = exports.blockItem = exports.fetchContentTypeData = exports.fetchDetailsData = void 0;
const qs_1 = require("qs");
const lodash_1 = require("lodash");
const utils_1 = require("../../utils");
const fetchDetailsData = async (id, queryParams, toggleNotification) => {
    try {
        const stringifiedProps = !(0, lodash_1.isEmpty)(queryParams)
            ? `?${(0, qs_1.stringify)(queryParams, { encode: false })}`
            : "";
        const { data } = await utils_1.axiosInstance.get((0, utils_1.getApiURL)(`moderate/single/${id}${stringifiedProps}`));
        return data;
    }
    catch (err) {
        (0, utils_1.handleAPIError)(err, toggleNotification);
    }
};
exports.fetchDetailsData = fetchDetailsData;
const fetchContentTypeData = async (uid, toggleNotification) => {
    try {
        const { data } = await utils_1.axiosInstance.get(`/content-type-builder/content-types/${uid}`);
        return data?.data;
    }
    catch (err) {
        (0, utils_1.handleAPIError)(err, toggleNotification);
    }
};
exports.fetchContentTypeData = fetchContentTypeData;
const blockItem = (id) => {
    return utils_1.axiosInstance.patch((0, utils_1.getApiURL)(`moderate/single/${id}/block`));
};
exports.blockItem = blockItem;
const unblockItem = (id) => {
    return utils_1.axiosInstance.patch((0, utils_1.getApiURL)(`moderate/single/${id}/unblock`));
};
exports.unblockItem = unblockItem;
const approveItem = (id) => {
    return utils_1.axiosInstance.patch((0, utils_1.getApiURL)(`moderate/single/${id}/approve`));
};
exports.approveItem = approveItem;
const rejectItem = (id) => {
    return utils_1.axiosInstance.patch((0, utils_1.getApiURL)(`moderate/single/${id}/reject`));
};
exports.rejectItem = rejectItem;
const deleteItem = (id) => {
    return utils_1.axiosInstance.delete((0, utils_1.getApiURL)(`moderate/single/${id}/delete`));
};
exports.deleteItem = deleteItem;
const blockItemThread = (id) => {
    return utils_1.axiosInstance.patch((0, utils_1.getApiURL)(`moderate/thread/${id}/block`));
};
exports.blockItemThread = blockItemThread;
const unblockItemThread = (id) => {
    return utils_1.axiosInstance.patch((0, utils_1.getApiURL)(`moderate/thread/${id}/unblock`));
};
exports.unblockItemThread = unblockItemThread;
const resolveReport = ({ id, reportId }) => {
    return utils_1.axiosInstance.patch((0, utils_1.getApiURL)(`moderate/single/${id}/report/${reportId}/resolve`));
};
exports.resolveReport = resolveReport;
const resolveCommentMultipleReports = ({ id, reportIds, }) => {
    return utils_1.axiosInstance.put((0, utils_1.getApiURL)(`moderate/single/${id}/report/resolve`), reportIds);
};
exports.resolveCommentMultipleReports = resolveCommentMultipleReports;
const resolveMultipleReports = (reportsIds) => utils_1.axiosInstance.put((0, utils_1.getApiURL)(`moderate/multiple/report/resolve`), reportsIds);
exports.resolveMultipleReports = resolveMultipleReports;
const resolveAllAbuseReportsForComment = (commentId) => utils_1.axiosInstance.put((0, utils_1.getApiURL)(`moderate/all/${commentId}/report/resolve`));
exports.resolveAllAbuseReportsForComment = resolveAllAbuseReportsForComment;
const resolveAllAbuseReportsForThread = (commentId) => utils_1.axiosInstance.put((0, utils_1.getApiURL)(`moderate/all/${commentId}/report/resolve-thread`));
exports.resolveAllAbuseReportsForThread = resolveAllAbuseReportsForThread;
const postComment = ({ threadId, body, author }) => {
    return utils_1.axiosInstance.post((0, utils_1.getApiURL)(`moderate/thread/${threadId}/postComment`), {
        content: body,
        author: author
    });
};
exports.postComment = postComment;
const updateComment = ({ id, body }) => {
    return utils_1.axiosInstance.put((0, utils_1.getApiURL)(`moderate/single/${id}/update`), {
        content: body,
    });
};
exports.updateComment = updateComment;
//# sourceMappingURL=api.js.map