"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const functions_1 = require("./../utils/functions");
const functions_2 = require("./utils/functions");
const controllers = {
    getService(name = "admin") {
        return (0, functions_1.getPluginService)(name);
    },
    async config(ctx) {
        try {
            return await this.getService().config();
        }
        catch (e) {
            throw (0, functions_2.throwError)(ctx, e);
        }
    },
    async settingsConfig(ctx) {
        try {
            return this.getService().config(true);
        }
        catch (e) {
            throw (0, functions_2.throwError)(ctx, e);
        }
    },
    async settingsUpdateConfig(ctx) {
        try {
            const { request: { body }, } = ctx;
            (0, functions_1.assertNotEmpty)(body);
            return this.getService().updateConfig(body);
        }
        catch (e) {
            throw (0, functions_2.throwError)(ctx, e);
        }
    },
    async settingsRestoreConfig(ctx) {
        try {
            return this.getService().restoreConfig();
        }
        catch (e) {
            throw (0, functions_2.throwError)(ctx, e);
        }
    },
    async settingsRestart(ctx) {
        try {
            await this.getService().restart();
            return ctx.send({ status: 200 });
        }
        catch (e) {
            throw (0, functions_2.throwError)(ctx, e);
        }
    },
    async findAll(ctx) {
        return this.getService().findAll(ctx.query);
    },
    async findReports(ctx) {
        return this.getService().findReports(ctx.query);
    },
    async findOne(ctx) {
        const { params = {}, query } = ctx;
        const { id } = (0, functions_2.parseParams)(params);
        try {
            return await this.getService().findOneAndThread(id, query);
        }
        catch (e) {
            throw (0, functions_2.throwError)(ctx, e);
        }
    },
    async blockComment(ctx) {
        const { params = {} } = ctx;
        const { id } = (0, functions_2.parseParams)(params);
        try {
            return await this.getService().blockComment(id, true);
        }
        catch (e) {
            throw (0, functions_2.throwError)(ctx, e);
        }
    },
    async unblockComment(ctx) {
        const { params = {} } = ctx;
        const { id } = (0, functions_2.parseParams)(params);
        try {
            return await this.getService().blockComment(id, false);
        }
        catch (e) {
            throw (0, functions_2.throwError)(ctx, e);
        }
    },
    async deleteComment(ctx) {
        const { params = {} } = ctx;
        const { id } = (0, functions_2.parseParams)(params);
        try {
            return await this.getService().deleteComment(id);
        }
        catch (e) {
            throw (0, functions_2.throwError)(ctx, e);
        }
    },
    async blockCommentThread(ctx) {
        const { params = {} } = ctx;
        const { id } = (0, functions_2.parseParams)(params);
        try {
            return await this.getService().blockCommentThread(id, true);
        }
        catch (e) {
            throw (0, functions_2.throwError)(ctx, e);
        }
    },
    async unblockCommentThread(ctx) {
        const { params = {} } = ctx;
        const { id } = (0, functions_2.parseParams)(params);
        try {
            return await this.getService().blockCommentThread(id, false);
        }
        catch (e) {
            throw (0, functions_2.throwError)(ctx, e);
        }
    },
    async resolveAbuseReport(ctx) {
        const { params = {} } = ctx;
        const { id: commentId, reportId } = (0, functions_2.parseParams)(params);
        try {
            return await this.getService().resolveAbuseReport(reportId, commentId);
        }
        catch (e) {
            throw (0, functions_2.throwError)(ctx, e);
        }
    },
    async resolveCommentMultipleAbuseReports(ctx) {
        const { params = {}, request } = ctx;
        const { body } = request;
        const { id: commentId } = (0, functions_2.parseParams)(params);
        (0, functions_1.assertNotEmpty)(body);
        try {
            return await this.getService().resolveCommentMultipleAbuseReports(body, commentId);
        }
        catch (e) {
            throw (0, functions_2.throwError)(ctx, e);
        }
    },
    async resolveAllAbuseReportsForComment(ctx) {
        const { params } = ctx;
        const { id: commentId } = (0, functions_2.parseParams)(params);
        try {
            return await this.getService().resolveAllAbuseReportsForComment(commentId);
        }
        catch (e) {
            throw (0, functions_2.throwError)(ctx, e);
        }
    },
    async resolveAllAbuseReportsForThread(ctx) {
        const { params } = ctx;
        const { id: commentId } = (0, functions_2.parseParams)(params);
        try {
            return await this.getService().resolveAllAbuseReportsForThread(commentId);
        }
        catch (e) {
            throw (0, functions_2.throwError)(ctx, e);
        }
    },
    async resolveMultipleAbuseReports(ctx) {
        const { request: { body }, } = ctx;
        (0, functions_1.assertNotEmpty)(body);
        try {
            return await this.getService().resolveMultipleAbuseReports(body);
        }
        catch (e) {
            throw (0, functions_2.throwError)(ctx, e);
        }
    },
    async postComment(ctx) {
        const { params = {}, request } = ctx;
        const { body } = request;
        const { id: threadId } = (0, functions_2.parseParams)(params);
        try {
            return await this.getService().postComment(threadId, body.content, body.author);
        }
        catch (e) {
            throw (0, functions_2.throwError)(ctx, e);
        }
    },
    async updateComment(ctx) {
        const { params = {}, request } = ctx;
        const { body } = request;
        const { id } = (0, functions_2.parseParams)(params);
        try {
            return await this.getService().updateComment(id, body.content);
        }
        catch (e) {
            throw (0, functions_2.throwError)(ctx, e);
        }
    },
    async approveComment(ctx) {
        const { id } = (0, functions_2.parseParams)(ctx.params || {});
        try {
            return await this.getService().approveComment(id);
        }
        catch (e) {
            throw (0, functions_2.throwError)(ctx, e);
        }
    },
    async rejectComment(ctx) {
        const { id } = (0, functions_2.parseParams)(ctx.params || {});
        try {
            return await this.getService().rejectComment(id);
        }
        catch (e) {
            throw (0, functions_2.throwError)(ctx, e);
        }
    },
};
exports.default = controllers;
//# sourceMappingURL=admin.js.map