"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const functions_1 = require("./../utils/functions");
const functions_2 = require("./utils/functions");
const parsers_1 = require("./utils/parsers");
const error_1 = __importDefault(require("../utils/error"));
const constants_1 = require("../utils/constants");
const controllers = {
    getService(name = "client") {
        return (0, functions_1.getPluginService)(name);
    },
    async findAllFlat(ctx) {
        const { params = {}, query, sort, pagination } = ctx;
        const { relation } = (0, functions_2.parseParams)(params);
        const { sort: querySort, pagination: queryPagination, fields, ...filterQuery } = query || {};
        try {
            (0, functions_1.assertParamsPresent)(params, ["relation"]);
            return this.getService("common").findAllFlat((0, parsers_1.flatInput)({
                relation,
                query: filterQuery,
                sort: sort || querySort,
                pagination: pagination || queryPagination,
                fields,
            }));
        }
        catch (e) {
            throw (0, functions_2.throwError)(ctx, e);
        }
    },
    async findAllInHierarchy(ctx) {
        const { params, query, sort } = ctx;
        const { relation } = (0, functions_2.parseParams)(params);
        const { sort: querySort, fields, ...filterQuery } = query || {};
        try {
            (0, functions_1.assertParamsPresent)(params, ["relation"]);
            return await this.getService("common").findAllInHierarchy({
                ...(0, parsers_1.flatInput)({
                    relation,
                    query: filterQuery,
                    sort: sort || querySort,
                    fields,
                }),
                dropBlockedThreads: true,
            });
        }
        catch (e) {
            throw (0, functions_2.throwError)(ctx, e);
        }
    },
    async findAllPerAuthor(ctx) {
        const { params = {}, query, sort, pagination } = ctx;
        const { id, type } = (0, functions_2.parseParams)(params);
        const { sort: querySort, pagination: queryPagination, fields, ...filterQuery } = query || {};
        try {
            (0, functions_1.assertParamsPresent)(params, ["id"]);
            return this.getService("common").findAllPerAuthor((0, parsers_1.flatInput)({
                query: filterQuery,
                sort: sort || querySort,
                pagination: pagination || queryPagination,
                fields,
            }), id, ![constants_1.AUTHOR_TYPE.GENERIC.toLowerCase(), constants_1.AUTHOR_TYPE.GENERIC].includes(type));
        }
        catch (e) {
            throw (0, functions_2.throwError)(ctx, e);
        }
    },
    async post(ctx) {
        const { request, params, state = {} } = ctx;
        const { relation } = (0, functions_2.parseParams)(params);
        const { user } = state;
        const { body } = request;
        try {
            (0, functions_1.assertParamsPresent)(params, ["relation"]);
            (0, functions_1.assertNotEmpty)(body);
            const entity = await this.getService().create(relation, body, user);
            if (entity) {
                return entity;
            }
            throw new error_1.default(400, "Comment hasn't been created");
        }
        catch (e) {
            throw (0, functions_2.throwError)(ctx, e);
        }
    },
    async put(ctx) {
        const { request, state, params = {} } = ctx;
        const { body } = request;
        const { user } = state;
        const { commentId, relation } = (0, functions_2.parseParams)(params);
        try {
            (0, functions_1.assertParamsPresent)(params, ["commentId", "relation"]);
            (0, functions_1.assertNotEmpty)(body);
            return await this.getService().update(commentId, relation, body, user);
        }
        catch (e) {
            throw (0, functions_2.throwError)(ctx, e);
        }
    },
    async reportAbuse(ctx) {
        const { request, state, params = {} } = ctx;
        const { body } = request;
        const { user } = state;
        const { relation, commentId } = (0, functions_2.parseParams)(params);
        try {
            (0, functions_1.assertParamsPresent)(params, ["commentId", "relation"]);
            (0, functions_1.assertNotEmpty)(body);
            if (!body.content) {
                throw new error_1.default(400, "Content field is required");
            }
            return await this.getService().reportAbuse(commentId, relation, body, user);
        }
        catch (e) {
            throw (0, functions_2.throwError)(ctx, e);
        }
    },
    async removeComment(ctx) {
        const { params, query, state: { user }, } = ctx;
        const { relation, commentId } = (0, functions_2.parseParams)(params);
        const { authorId } = (0, functions_2.parseParams)(query);
        try {
            (0, functions_1.assertParamsPresent)(params, ["commentId", "relation"]);
            (0, functions_1.assertParamsPresent)(query, ["authorId"]);
            if (authorId || user?.id) {
                return await this.getService().markAsRemoved(commentId, relation, authorId, user);
            }
            return new error_1.default(400, "Not provided authorId");
        }
        catch (e) {
            if (!e.isBoom) {
                (0, functions_2.throwError)(ctx, e);
            }
            throw e;
        }
    },
};
exports.default = controllers;
//# sourceMappingURL=client.js.map