"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.flatInput = void 0;
const error_1 = __importDefault(require("../../utils/error"));
const functions_1 = require("../../utils/functions");
const flatInput = (payload) => {
    const { relation, query, sort, pagination, fields } = payload;
    const { populate = {}, filterBy, filterByValue, ...restQuery } = query;
    const filters = restQuery?.filters || restQuery;
    const orOperator = (filters?.$or || []).filter((_) => !Object.keys(_).includes("removed"));
    let basePopulate = {
        ...populate,
    };
    let threadOfPopulate = {
        threadOf: {
            populate: {
                authorUser: true,
                ...populate,
            },
        },
    };
    if (populate.author) {
        const { author, ...restPopulate } = populate;
        basePopulate = {
            ...restPopulate,
            authorUser: author,
        };
        threadOfPopulate = {
            threadOf: {
                populate: {
                    authorUser: author,
                    ...restPopulate,
                },
            },
        };
    }
    if (filterBy === "DATE_CREATED") {
        const date = new Date(filterByValue);
        if (!filterByValue || Number.isNaN(+date)) {
            throw new error_1.default(400, 'Invalid date specified in "filterByValue"');
        }
        const start = date.setHours(0, 0, 0, 0);
        const end = date.setHours(23, 59, 59, 999);
        filters.createdAt = {
            $between: [start, end],
        };
    }
    if (filterBy === "APPROVAL_STATUS") {
        (0, functions_1.assertNotEmpty)(filterByValue, new error_1.default(400, 'Empty "filterByValue" parameter'));
        filters.approvalStatus = filterByValue;
    }
    return {
        query: {
            ...filters,
            $or: [...orOperator, { removed: { $null: true } }, { removed: false }],
            related: relation,
        },
        populate: {
            ...basePopulate,
            ...threadOfPopulate,
        },
        pagination,
        sort,
        fields,
    };
};
exports.flatInput = flatInput;
//# sourceMappingURL=parsers.js.map