"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
const lodash_1 = require("lodash");
const comment_1 = __importDefault(require("../../../content-types/comment"));
const parsers_1 = require("../../controllers/utils/parsers");
const functions_1 = require("../../utils/functions");
const constants_1 = require("../../utils/constants");
module.exports = ({ strapi, nexus }) => {
    const { nonNull, intArg, arg } = nexus;
    const { service: getService } = strapi.plugin("graphql");
    const { args } = getService("internals");
    const { naming: { getFiltersInputTypeName }, } = getService("utils");
    return {
        type: "ResponseFindAllPerAuthor",
        args: {
            authorId: nonNull(intArg()),
            authorType: arg({ type: 'AuthorType' }),
            filters: getFiltersInputTypeName(comment_1.default),
            pagination: args.PaginationArg,
            sort: args.SortArg,
        },
        async resolve(obj, args) {
            const { authorId, authorType, filters, sort, pagination } = args;
            const isStrapiUser = authorType !== constants_1.AUTHOR_TYPE.GENERIC;
            return await (0, functions_1.getPluginService)("common").findAllPerAuthor((0, parsers_1.flatInput)({
                query: (0, functions_1.getPluginService)("gql").graphQLFiltersToStrapiQuery(filters, comment_1.default),
                sort,
                pagination: pagination
                    ? {
                        ...pagination,
                        withCount: !(0, lodash_1.isEmpty)(pagination),
                    }
                    : undefined,
            }), authorId, isStrapiUser);
        },
    };
};
//# sourceMappingURL=findAllPerAuthor.js.map