"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getAuthorName = exports.resolveUserContextError = exports.buildConfigQueryProp = exports.buildAuthorModel = exports.convertContentTypeNameToSlug = exports.filterOurResolvedReports = exports.getModelUid = exports.getRelatedGroups = exports.isEqualEntity = exports.buildNestedStructure = void 0;
const error_1 = __importDefault(require("./../../utils/error"));
const constants_1 = require("./../../utils/constants");
const lodash_1 = require("lodash");
const buildNestedStructure = (entities, id = null, field = "threadOf", dropBlockedThreads = false, blockNestedThreads = false) => entities
    .filter((entity) => {
    const entityField = (0, lodash_1.get)(entity, field);
    if (entityField === null && id === null) {
        return true;
    }
    let data = entityField;
    if (data && typeof id === "string") {
        data = data.toString();
    }
    return ((data && data === id) ||
        ((0, lodash_1.isObject)(entityField) && entityField.id === id));
})
    .map((entity) => ({
    ...entity,
    [field]: undefined,
    related: undefined,
    blockedThread: blockNestedThreads || entity.blockedThread,
    children: entity.blockedThread && dropBlockedThreads
        ? []
        : (0, exports.buildNestedStructure)(entities, entity.id, field, dropBlockedThreads, entity.blockedThread),
}));
exports.buildNestedStructure = buildNestedStructure;
const isEqualEntity = (existing, data, user) => {
    const { author: existingAuthor = {} } = existing;
    const { author } = data;
    if (data.approvalStatus && existing.approvalStatus !== data.approvalStatus) {
        return false;
    }
    if (user) {
        const existingUserId = existingAuthor?.id || existingAuthor;
        const receivedUserId = user?.id || author?.id;
        return receivedUserId && existingUserId === receivedUserId;
    }
    return existingAuthor.id === author?.id;
};
exports.isEqualEntity = isEqualEntity;
const getRelatedGroups = (related) => related.split(constants_1.REGEX.relatedUid).filter((s) => s && s.length > 0);
exports.getRelatedGroups = getRelatedGroups;
const getModelUid = (name) => {
    return strapi.plugin("comments").contentTypes[name]?.uid;
};
exports.getModelUid = getModelUid;
const filterOurResolvedReports = (item) => item
    ? {
        ...item,
        reports: (item.reports || []).filter((report) => !report.resolved),
    }
    : item;
exports.filterOurResolvedReports = filterOurResolvedReports;
const convertContentTypeNameToSlug = (str) => {
    const plainConversion = str.replace(/[A-Z]/g, (letter) => `-${letter.toLowerCase()}`);
    return (0, lodash_1.first)(plainConversion) === "-"
        ? plainConversion.slice(1, plainConversion.length)
        : plainConversion;
};
exports.convertContentTypeNameToSlug = convertContentTypeNameToSlug;
const buildAuthorModel = (item, blockedAuthorProps, fieldsToPopulate = []) => {
    const { authorUser, authorId, authorName, authorEmail, authorAvatar, ...rest } = item;
    let author = {};
    if (authorUser) {
        author = fieldsToPopulate.reduce((prev, curr) => ({
            ...prev,
            [curr]: authorUser[curr],
        }), {
            id: authorUser.id,
            name: authorUser.username,
            email: authorUser.email,
            avatar: (0, lodash_1.isString)(authorUser.avatar) || (0, lodash_1.isObject)(authorUser.avatar)
                ? authorUser.avatar
                : undefined,
        });
    }
    else if (authorId) {
        author = {
            id: authorId,
            name: authorName,
            email: authorEmail,
            avatar: authorAvatar,
        };
    }
    author = (0, lodash_1.isEmpty)(author) ? author : Object.fromEntries(Object.entries(author)
        .filter(([name]) => !blockedAuthorProps.includes(name)));
    return {
        ...rest,
        author,
    };
};
exports.buildAuthorModel = buildAuthorModel;
const buildConfigQueryProp = (prop = "") => ((0, lodash_1.isArray)(prop) ? prop.join(".") : prop ?? "");
exports.buildConfigQueryProp = buildConfigQueryProp;
const resolveUserContextError = (user) => {
    if (user) {
        throw new error_1.default(401, "Not authenticated");
    }
    else {
        throw new error_1.default(403, "Not authorized");
    }
};
exports.resolveUserContextError = resolveUserContextError;
const getAuthorName = (author) => {
    const { lastname, username, firstname } = author;
    if (lastname)
        return `${firstname} ${lastname}`;
    else
        return username || firstname;
};
exports.getAuthorName = getAuthorName;
//# sourceMappingURL=functions.js.map