"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.parsePaginationsQuery = exports.parseFieldsQuery = exports.parseSortQuery = void 0;
const constants_1 = require("./../../utils/constants");
const lodash_1 = require("lodash");
const parseSortQuery = (sort, query = {}) => {
    if (sort && ((0, lodash_1.isString)(sort) || (0, lodash_1.isArray)(sort))) {
        return {
            ...query,
            orderBy: ((0, lodash_1.isString)(sort) ? [sort] : sort)
                .map((_) => (constants_1.REGEX.sorting.test(_) ? _ : `${_}:asc`))
                .reduce((prev, curr) => {
                const [type = "asc", ...parts] = curr.split(":").reverse();
                return { ...(0, lodash_1.set)(prev, parts.reverse().join("."), type) };
            }, {}),
        };
    }
    return query;
};
exports.parseSortQuery = parseSortQuery;
const parseFieldsQuery = (fields, query = {}, defaultSelect = []) => {
    if (!(0, lodash_1.isNil)(fields)) {
        return {
            ...query,
            select: (0, lodash_1.isArray)(fields) ? (0, lodash_1.uniq)([...fields, ...defaultSelect]) : fields,
        };
    }
    return query;
};
exports.parseFieldsQuery = parseFieldsQuery;
const parsePaginationsQuery = (pagination, query = {}, defaults = []) => {
    if (pagination && (0, lodash_1.isObject)(pagination)) {
        const parsedpagination = Object.keys(pagination).reduce((prev, curr) => ({
            ...prev,
            [curr]: parseInt((0, lodash_1.get)(pagination, curr)),
        }), {});
        const { page = 1, pageSize = defaults.PAGE_SIZE, start = 0, limit = defaults.PAGE_SIZE, } = parsedpagination;
        const paginationByPage = !(0, lodash_1.isNil)(parsedpagination?.page) || !(0, lodash_1.isNil)(parsedpagination?.pageSize);
        const metapagination = paginationByPage
            ? {
                pagination: {
                    page,
                    pageSize,
                },
            }
            : {
                pagination: {
                    start,
                    limit,
                },
            };
        return [{
                ...metapagination,
            }, {
                ...query,
                offset: paginationByPage ? (page - 1) * pageSize : start,
                limit: paginationByPage ? pageSize : limit,
            }];
    }
    return [{}, query];
};
exports.parsePaginationsQuery = parsePaginationsQuery;
//# sourceMappingURL=parsers.js.map