"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
const lodash_1 = require("lodash");
const constants_1 = require("./server/utils/constants");
const server_1 = __importDefault(require("./server"));
const content_types_1 = __importDefault(require("./content-types"));
module.exports = () => ({
    ...server_1.default,
    contentTypes: content_types_1.default,
    config: {
        ...server_1.default.config,
        default: () => ({
            ...server_1.default.config.default,
        }),
        validator: (config) => {
            const enabledCollections = config[constants_1.CONFIG_PARAMS.ENABLED_COLLECTIONS];
            const enabledCollectionsValid = enabledCollections.filter((_) => !constants_1.REGEX.uid.test(_)).length ===
                0;
            if (!enabledCollectionsValid) {
                throw new Error(`'enabledCollections' must contain Content Types identifiers in the format like 'api::<collection name>.<content type name>'`);
            }
            const moderatorRoles = config[constants_1.CONFIG_PARAMS.MODERATOR_ROLES];
            const moderatorRolesValid = moderatorRoles.filter((_) => !(0, lodash_1.isString)(_)).length === 0;
            if (!moderatorRolesValid) {
                throw new Error(`'moderatorRoles' must roles keys`);
            }
            const approvalFlow = config[constants_1.CONFIG_PARAMS.APPROVAL_FLOW];
            const approvalFlowValid = approvalFlow.filter((_) => !constants_1.REGEX.uid.test(_)).length === 0;
            if (!approvalFlowValid) {
                throw new Error(`'approvalFlow' must contain Content Types identifiers in the format like 'api::<collection name>.<content type name>'`);
            }
            const entryLabels = config[constants_1.CONFIG_PARAMS.ENTRY_LABEL];
            const entryLabelKeysValid = Object.keys(entryLabels)
                .filter((_) => _ !== "*")
                .filter((_) => !(constants_1.REGEX.uid.test(_) &&
                (0, lodash_1.isArray)(entryLabels[_]) &&
                !(0, lodash_1.isEmpty)(entryLabels[_]))).length === 0;
            if (!entryLabelKeysValid) {
                throw new Error(`'entryLabel' must contain records in the format like 'api::<collection name>.<content type name>': ['Field1', 'field_2']`);
            }
        },
    },
});
//# sourceMappingURL=strapi-server.js.map